Tests — Ryser 0.0.10 documentation

### Navigation

- index
- modules |
- Ryser 0.0.10 documentation »

# Tests

## Designs

class `designs_tests.` `TestLatin`(methodName='runTest')

  Testing of latin square components.

## Graphs

## Hall

## Output

class `output_tests.` `TestDictToString`(methodName='runTest')

  Testing of string conversion.

class `output_tests.` `TestDictToStringSimple`(methodName='runTest')

  Testing of string conversion.

class `output_tests.` `TestRowString`(methodName='runTest')

  Testing of row to string.

## Utils

### Navigation

- index
- modules |
- Ryser 0.0.10 documentation »